.. _api_association:

.. py:module:: pynetdicom.association

Association (:mod:`pynetdicom.association`)
============================================

Representation of a DICOM Association between two Application Entities and
one of pynetdicom's two main user classes.

.. currentmodule:: pynetdicom.association

.. autosummary::
   :toctree: generated/

   Association
   ServiceUser
